@@ -1,12 +1,12 @@
+from imaplib import IMAP4, IMAP4_SSL
 import logging
 
-logger = logging.getLogger(__name__)
-
-from imaplib import IMAP4, IMAP4_SSL
+from django.conf import settings
 
 from .base import EmailTransport, MessageParseError
 
-from django.conf import settings
+
+logger = logging.getLogger(__name__)
 
 
 class ImapTransport(EmailTransport):
@@ -36,7 +36,13 @@ class ImapTransport(EmailTransport):
     def _get_all_message_ids(self):
         # Fetch all the message uids
         response, message_ids = self.server.uid('search', None, 'ALL')
-        return message_ids[0].split(' ')
+        message_id_string = message_ids[0].strip()
+        # Usually `message_id_string` will be a list of space-separated
+        # ids; we must make sure that it isn't an empty string before
+        # splitting into individual UIDs.
+        if message_id_string:
+            return message_id_string.split(' ')
+        return []
 
     def _get_small_message_ids(self, message_ids):
         # Using existing message uids, get the sizes and
@@ -90,6 +96,6 @@ class ImapTransport(EmailTransport):
             if self.archive:
                 self.server.uid('copy', uid, self.archive)
 
-            self.server.uid('store', uid, "+FLAGS", "\\Deleted")
+            self.server.uid('store', uid, "+FLAGS", "(\\Deleted)")
         self.server.expunge()
         return
